@@ -14,9 +14,14 @@
  * limitations under the License.
  */
 
+mod errors;
 mod prepare;
 mod version_checker;
 
+pub(crate) use errors::HeapBaseError;
+pub(crate) use errors::PrepareError;
 pub(crate) use prepare::prepare_module;
 pub(crate) use version_checker::check_sdk_version;
 pub(crate) use version_checker::check_it_version;
+
+pub(self) type PrepareResult<T> = std::result::Result<T, PrepareError>;
